/*******************************************************************************
 * Copyright 2011 @ Kapil Viren Ahuja
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package com.kapil.framework.crypto;

/**
 * Contract for utility classes that provide message digest functionality.
 */
public interface IDigester
{
    /**
     * Converts a text message into its equivalent digest.
     *
     * @param text A {@link java.lang.String} containing the text to be digested.
     * @return A printable {@link java.lang.String} digest.
     */
    String digest(String text);
    
    
    /**
     * Computes digest for a text message.
     *
     * @param text {@link java.lang.String} text.
     * @return An array of bytes containing the digest.
     */
    byte[] getRawDigest(String text);
}


