/*******************************************************************************
 * Copyright 2011 @ Kapil Viren Ahuja
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 ******************************************************************************/
package com.kapil.framework.crypto;


/**
 * Generates a {@link String} which is a random and unique. It can be used as unique token in any application. The
 * String is uses the <code>SSHA</code> algorithm and randon numbers to generate the tokens.
 */
public final class RandomTokenGenerator
{
    private static final SaltedSecureHashDigester DIGESTER = new SaltedSecureHashDigester();


    /**
     * Made private to prevent instances from being created.
     */
    private RandomTokenGenerator()
    {
    }


    /**
     * Generates a new unique token by attempting to create an <code>SSHA</code> digest of a random number.
     * 
     * @return A {@link java.lang.String} that can be used as a unique token.
     */
    public static String getUniqueToken()
    {
        return Base64Util.encode(DIGESTER.getRawDigest(String.valueOf(Math.random())));
    }
}
